summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Makefile12
-rw-r--r--board/freescale/mx6q_arm2/Makefile (renamed from board/freescale/mx6q_sabreauto/Makefile)2
-rw-r--r--board/freescale/mx6q_arm2/config.mk (renamed from board/freescale/mx6q_sabreauto/config.mk)0
-rw-r--r--board/freescale/mx6q_arm2/flash_header.S (renamed from board/freescale/mx6q_sabreauto/flash_header.S)0
-rw-r--r--board/freescale/mx6q_arm2/lowlevel_init.S (renamed from board/freescale/mx6q_sabreauto/lowlevel_init.S)0
-rw-r--r--board/freescale/mx6q_arm2/mx6q_arm2.c (renamed from board/freescale/mx6q_sabreauto/mx6q_sabreauto.c)18
-rw-r--r--board/freescale/mx6q_arm2/u-boot.lds (renamed from board/freescale/mx6q_sabreauto/u-boot.lds)4
-rw-r--r--drivers/net/mxc_fec.c4
-rw-r--r--include/asm-arm/mach-types.h13
-rw-r--r--include/configs/mx6q_arm2.h (renamed from include/configs/mx6q_sabreauto.h)6
-rw-r--r--include/configs/mx6q_arm2_iram.h (renamed from include/configs/mx6q_sabreauto_iram.h)6
-rw-r--r--include/configs/mx6q_arm2_lpddr2.h (renamed from include/configs/mx6q_sabreauto_lpddr2.h)7
-rw-r--r--include/configs/mx6q_arm2_mfg.h (renamed from include/configs/mx6q_sabreauto_mfg.h)6
-rw-r--r--include/configs/mx6q_sabrelite.h2
14 files changed, 48 insertions, 32 deletions
diff --git a/Makefile b/Makefile
index f389257..8a2bfc6 100644
--- a/Makefile
+++ b/Makefile
@@ -3306,15 +3306,15 @@ mx53_evk_mfg_config \
mx53_evk_config : unconfig
@$(MKCONFIG) $(@:_config=) arm arm_cortexa8 mx53_evk freescale mx53
-mx6q_sabreauto_config \
-mx6q_sabreauto_mfg_config \
-mx6q_sabreauto_lpddr2_config \
-mx6q_sabreauto_iram_config : unconfig
+mx6q_arm2_config \
+mx6q_arm2_mfg_config \
+mx6q_arm2_lpddr2_config \
+mx6q_arm2_iram_config : unconfig
@[ -z "$(findstring iram_,$@)" ] || \
- { echo "TEXT_BASE = 0x00910000" >$(obj)board/freescale/mx6q_sabreauto/config.tmp ; \
+ { echo "TEXT_BASE = 0x00910000" >$(obj)board/freescale/mx6q_arm2/config.tmp ; \
echo "... with iram configuration" ; \
}
- @$(MKCONFIG) $(@:_config=) arm arm_cortexa8 mx6q_sabreauto freescale mx6
+ @$(MKCONFIG) $(@:_config=) arm arm_cortexa8 mx6q_arm2 freescale mx6
mx6q_sabrelite_config : unconfig
@$(MKCONFIG) $(@:_config=) arm arm_cortexa8 mx6q_sabrelite freescale mx6
diff --git a/board/freescale/mx6q_sabreauto/Makefile b/board/freescale/mx6q_arm2/Makefile
index 60e5fc4..c0b30e4 100644
--- a/board/freescale/mx6q_sabreauto/Makefile
+++ b/board/freescale/mx6q_arm2/Makefile
@@ -21,7 +21,7 @@ include $(TOPDIR)/config.mk
LIB = $(obj)lib$(BOARD).a
-COBJS := mx6q_sabreauto.o
+COBJS := $(BOARD).o
SOBJS := lowlevel_init.o flash_header.o
SRCS := $(SOBJS:.o=.S) $(COBJS:.o=.c)
diff --git a/board/freescale/mx6q_sabreauto/config.mk b/board/freescale/mx6q_arm2/config.mk
index a0ce2a1..a0ce2a1 100644
--- a/board/freescale/mx6q_sabreauto/config.mk
+++ b/board/freescale/mx6q_arm2/config.mk
diff --git a/board/freescale/mx6q_sabreauto/flash_header.S b/board/freescale/mx6q_arm2/flash_header.S
index 441694e..441694e 100644
--- a/board/freescale/mx6q_sabreauto/flash_header.S
+++ b/board/freescale/mx6q_arm2/flash_header.S
diff --git a/board/freescale/mx6q_sabreauto/lowlevel_init.S b/board/freescale/mx6q_arm2/lowlevel_init.S
index 2ac77b9..2ac77b9 100644
--- a/board/freescale/mx6q_sabreauto/lowlevel_init.S
+++ b/board/freescale/mx6q_arm2/lowlevel_init.S
diff --git a/board/freescale/mx6q_sabreauto/u-boot.lds b/board/freescale/mx6q_arm2/u-boot.lds
index f3ebb48..e800b70 100644
--- a/board/freescale/mx6q_sabreauto/u-boot.lds
+++ b/board/freescale/mx6q_arm2/u-boot.lds
@@ -38,9 +38,9 @@ SECTIONS
{
/* WARNING - the following is hand-optimized to fit within */
/* the sector layout of our flash chips! XXX FIXME XXX */
- board/freescale/mx6q_sabreauto/flash_header.o (.text.flasheader)
+ board/freescale/mx6q_arm2/flash_header.o (.text.flasheader)
cpu/arm_cortexa8/start.o
- board/freescale/mx6q_sabreauto/libmx6q_sabreauto.a (.text)
+ board/freescale/mx6q_arm2/libmx6q_arm2.a (.text)
lib_arm/libarm.a (.text)
net/libnet.a (.text)
drivers/mtd/libmtd.a (.text)
diff --git a/drivers/net/mxc_fec.c b/drivers/net/mxc_fec.c
index 093b4e4..4f9f34d 100644
--- a/drivers/net/mxc_fec.c
+++ b/drivers/net/mxc_fec.c
@@ -79,7 +79,7 @@
#if defined (CONFIG_MX6Q)
extern int mx6_rgmii_rework(char *devname, int phy_addr);
#endif
-#ifdef CONFIG_MX6Q_SABREAUTO
+#ifdef CONFIG_MX6Q_ARM2
#define PHY_MIPSCR_LINK_UP (0x1 << 10)
#define PHY_MIPSCR_SPEED_MASK (0x3 << 14)
#define PHY_MIPSCR_1000M (0x2 << 14)
@@ -339,7 +339,7 @@ static void setFecDuplexSpeed(volatile fec_t *fecp, unsigned char addr,
}
/* for AR8031 PHY */
-#ifdef CONFIG_MX6Q_SABREAUTO
+#ifdef CONFIG_MX6Q_ARM2
ret = 100;
/* set default mode to 100M full duplex */
dup_spd = _100BASET | (FULL << 16);
diff --git a/include/asm-arm/mach-types.h b/include/asm-arm/mach-types.h
index 8d8e14c..f5e98af 100644
--- a/include/asm-arm/mach-types.h
+++ b/include/asm-arm/mach-types.h
@@ -3256,6 +3256,7 @@ extern unsigned int __machine_arch_type;
#define MACH_TYPE_MX53_PCBA 3274
#define MACH_TYPE_MX6Q_SABREAUTO 3529
#define MACH_TYPE_MX6Q_SABRELITE 3769
+#define MACH_TYPE_MX6Q_ARM2 3837
#ifdef CONFIG_ARCH_EBSA110
# ifdef machine_arch_type
@@ -42173,6 +42174,18 @@ extern unsigned int __machine_arch_type;
# define machine_is_mx6q_sabrelite() (0)
#endif
+#ifdef CONFIG_MACH_MX6Q_ARM2
+# ifdef machine_arch_type
+# undef machine_arch_type
+# define machine_arch_type __machine_arch_type
+# else
+# define machine_arch_type MACH_TYPE_MX6Q_ARM2
+# endif
+# define machine_is_mx6q_arm2() (machine_arch_type == MACH_TYPE_MX6Q_ARM2)
+#else
+# define machine_is_mx6q_arm2() (0)
+#endif
+
/*
* These have not yet been registered
*/
diff --git a/include/configs/mx6q_sabreauto.h b/include/configs/mx6q_arm2.h
index 871633a..a531cb8 100644
--- a/include/configs/mx6q_sabreauto.h
+++ b/include/configs/mx6q_arm2.h
@@ -1,7 +1,7 @@
/*
* Copyright (C) 2010-2011 Freescale Semiconductor, Inc.
*
- * Configuration settings for the MX6Q SABRE Automotive Infotainment Freescale board.
+ * Configuration settings for the MX6Q Armadillo2 Freescale board.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
@@ -28,7 +28,7 @@
#define CONFIG_ARMV7 /* This is armv7 Cortex-A9 CPU core */
#define CONFIG_MXC
#define CONFIG_MX6Q
-#define CONFIG_MX6Q_SABREAUTO
+#define CONFIG_MX6Q_ARM2
#define CONFIG_FLASH_HEADER
#define CONFIG_FLASH_HEADER_OFFSET 0x400
#define CONFIG_MX6_CLK32 32768
@@ -133,7 +133,7 @@
* Miscellaneous configurable options
*/
#define CONFIG_SYS_LONGHELP /* undef to save memory */
-#define CONFIG_SYS_PROMPT "MX6Q SABREAUTO U-Boot > "
+#define CONFIG_SYS_PROMPT "MX6Q ARM2 U-Boot > "
#define CONFIG_AUTO_COMPLETE
#define CONFIG_SYS_CBSIZE 256 /* Console I/O Buffer Size */
/* Print Buffer Size */
diff --git a/include/configs/mx6q_sabreauto_iram.h b/include/configs/mx6q_arm2_iram.h
index 50cac89..f3375d1 100644
--- a/include/configs/mx6q_sabreauto_iram.h
+++ b/include/configs/mx6q_arm2_iram.h
@@ -1,7 +1,7 @@
/*
* Copyright (C) 2010-2011 Freescale Semiconductor, Inc.
*
- * Configuration settings for the MX6Q SABRE Automotive Infotainment Freescale board.
+ * Configuration settings for the MX6Q Armadillo2 Freescale board.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
@@ -29,7 +29,7 @@
#define CONFIG_MXC
#define CONFIG_MX6Q
-#define CONFIG_MX6Q_SABREAUTO
+#define CONFIG_MX6Q_ARM2
#define CONFIG_FLASH_HEADER
#define CONFIG_FLASH_HEADER_OFFSET 0x400
#define CONFIG_MX6_CLK32 32768
@@ -115,7 +115,7 @@
/*
* Miscellaneous configurable options
*/
-#define CONFIG_SYS_PROMPT "MX6Q SABREAUTO IRAM U-Boot > "
+#define CONFIG_SYS_PROMPT "MX6Q ARM2 IRAM U-Boot > "
#define CONFIG_SYS_CBSIZE 256 /* Console I/O Buffer Size */
/* Print Buffer Size */
#define CONFIG_SYS_PBSIZE (CONFIG_SYS_CBSIZE + sizeof(CONFIG_SYS_PROMPT) + 16)
diff --git a/include/configs/mx6q_sabreauto_lpddr2.h b/include/configs/mx6q_arm2_lpddr2.h
index bcc9dcb..9847aa1 100644
--- a/include/configs/mx6q_sabreauto_lpddr2.h
+++ b/include/configs/mx6q_arm2_lpddr2.h
@@ -1,8 +1,7 @@
/*
* Copyright (C) 2010-2011 Freescale Semiconductor, Inc.
*
- * Configuration settings for the MX6Q SABRE Automotive
- * Infotainment Freescale board.
+ * Configuration settings for the MX6Q Armadillo2 Freescale board.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
@@ -30,7 +29,7 @@
#define CONFIG_ARMV7 /* This is armv7 Cortex-A9 CPU core */
#define CONFIG_MXC
#define CONFIG_MX6Q
-#define CONFIG_MX6Q_SABREAUTO
+#define CONFIG_MX6Q_ARM2
#define CONFIG_FLASH_HEADER
#define CONFIG_FLASH_HEADER_OFFSET 0x400
#define CONFIG_MX6_CLK32 32768
@@ -135,7 +134,7 @@
* Miscellaneous configurable options
*/
#define CONFIG_SYS_LONGHELP /* undef to save memory */
-#define CONFIG_SYS_PROMPT "MX6Q SABREAUTO U-Boot > "
+#define CONFIG_SYS_PROMPT "MX6Q ARM2 U-Boot > "
#define CONFIG_AUTO_COMPLETE
#define CONFIG_SYS_CBSIZE 256 /* Console I/O Buffer Size */
/* Print Buffer Size */
diff --git a/include/configs/mx6q_sabreauto_mfg.h b/include/configs/mx6q_arm2_mfg.h
index de5431e..87856e7 100644
--- a/include/configs/mx6q_sabreauto_mfg.h
+++ b/include/configs/mx6q_arm2_mfg.h
@@ -1,7 +1,7 @@
/*
* Copyright (C) 2010-2011 Freescale Semiconductor, Inc.
*
- * Configuration settings for the MX6Q SABRE Automotive Infotainment Freescale board.
+ * Configuration settings for the MX6Q Armadillo2 Freescale board.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
@@ -28,7 +28,7 @@
#define CONFIG_ARMV7 /* This is armv7 Cortex-A9 CPU core */
#define CONFIG_MXC
#define CONFIG_MX6Q
-#define CONFIG_MX6Q_SABREAUTO
+#define CONFIG_MX6Q_ARM2
#define CONFIG_FLASH_HEADER
#define CONFIG_FLASH_HEADER_OFFSET 0x400
#define CONFIG_MX6_CLK32 32768
@@ -122,7 +122,7 @@
* Miscellaneous configurable options
*/
#define CONFIG_SYS_LONGHELP /* undef to save memory */
-#define CONFIG_SYS_PROMPT "MX6Q SABREAUTO-MFG U-Boot > "
+#define CONFIG_SYS_PROMPT "MX6Q ARM2-MFG U-Boot > "
#define CONFIG_AUTO_COMPLETE
#define CONFIG_SYS_CBSIZE 256 /* Console I/O Buffer Size */
/* Print Buffer Size */
diff --git a/include/configs/mx6q_sabrelite.h b/include/configs/mx6q_sabrelite.h
index dd7c442..7b2fadb 100644
--- a/include/configs/mx6q_sabrelite.h
+++ b/include/configs/mx6q_sabrelite.h
@@ -1,7 +1,7 @@
/*
* Copyright (C) 2011 Freescale Semiconductor, Inc.
*
- * Configuration settings for the MX6Q SABRE Automotive Infotainment Freescale board.
+ * Configuration settings for the MX6Q SABRE-Lite Freescale board.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License as
diff --git a/board/freescale/mx6q_sabreauto/mx6q_sabreauto.c b/board/freescale/mx6q_arm2/mx6q_arm2.c
index 1c36e77..54873f3 100644
--- a/board/freescale/mx6q_sabreauto/mx6q_sabreauto.c
+++ b/board/freescale/mx6q_arm2/mx6q_arm2.c
@@ -442,19 +442,23 @@ int usdhc_gpio_init(bd_t *bis)
switch (index) {
case 0:
mxc_iomux_v3_setup_multiple_pads(mx6q_usdhc1_pads,
- sizeof(mx6q_usdhc1_pads) / sizeof(mx6q_usdhc1_pads[0]));
+ sizeof(mx6q_usdhc1_pads) /
+ sizeof(mx6q_usdhc1_pads[0]));
break;
case 1:
mxc_iomux_v3_setup_multiple_pads(mx6q_usdhc2_pads,
- sizeof(mx6q_usdhc2_pads) / sizeof(mx6q_usdhc2_pads[0]));
+ sizeof(mx6q_usdhc2_pads) /
+ sizeof(mx6q_usdhc2_pads[0]));
break;
case 2:
mxc_iomux_v3_setup_multiple_pads(mx6q_usdhc3_pads,
- sizeof(mx6q_usdhc3_pads) / sizeof(mx6q_usdhc3_pads[0]));
+ sizeof(mx6q_usdhc3_pads) /
+ sizeof(mx6q_usdhc3_pads[0]));
break;
case 3:
mxc_iomux_v3_setup_multiple_pads(mx6q_usdhc4_pads,
- sizeof(mx6q_usdhc4_pads) / sizeof(mx6q_usdhc4_pads[0]));
+ sizeof(mx6q_usdhc4_pads) /
+ sizeof(mx6q_usdhc4_pads[0]));
break;
default:
printf("Warning: you configured more USDHC controllers"
@@ -484,7 +488,7 @@ int board_mmc_init(bd_t *bis)
#ifdef CONFIG_GET_DDR_TARGET_DELAY
u32 get_ddr_delay(struct fsl_esdhc_cfg *cfg)
{
/* No delay required on SABRE Auto board SD ports */
return 0;
}
#endif
@@ -602,7 +606,7 @@ int board_init(void)
setup_boot_device();
/* board id for linux */
- gd->bd->bi_arch_number = MACH_TYPE_MX6Q_SABREAUTO;
+ gd->bd->bi_arch_number = MACH_TYPE_MX6Q_ARM2;
/* address of boot parameters */
gd->bd->bi_boot_params = PHYS_SDRAM_1 + 0x100;
@@ -731,7 +735,7 @@ void enet_board_init(void)
int checkboard(void)
{
- printf("Board: MX6Q-SABREAUTO:[ ");
+ printf("Board: MX6Q-ARM2:[ ");
switch (__REG(SRC_BASE_ADDR + 0x8)) {
case 0x0001:
@@ -484,7 +488,7 @@ int board_mmc_init(bd_t *bis)
u32 get_ddr_delay(struct fsl_esdhc_cfg *cfg)
{
- /* No delay required on SABRE Auto board SD ports */
+ /* No delay required on ARM2 board SD ports */
return 0;
}